==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/DriverProviderEvent_EventProducerNotifier.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;

import com.ebmwebsourcing.easybox.impl.AbstractJaxbModelObject;

public class DriverProviderEvent_EventProducerNotifier extends AbstractEventProducerNotifier {

	public DriverProviderEvent_EventProducerNotifier(ProviderConfiguration configuration, WSOUIJaxbContextItf context) throws WSOUIException {
		super(configuration, context);
		this.getSubscriptionManager().setTopicSet(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicSet.xml"));
		this.getSubscriptionManager().setTopicNamespace(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicNS.xml"));
	}

	@Override
	public void setPeriodEvent() {
		this.setPeriodEvent(0); // Set the period to send event (in ms).
	}


	@Override
	public Object createPeriodicallyEvent() throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeProcessingRequest(String methodName, Object request) throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeSendResponse(String methodName, Object request, Object response) throws WSOUIException {
		return null;
//		if(methodName.toLowerCase().equals("subscribe")) {
//			OfferEvent event = new OfferEvent();
//			event.setUid(UUID.randomUUID().toString());
//			Resources value = new Resources();
//			value.setQuantity(5.0);
//			value.setType("driver");
//			event.setProvider("driver");
//			event.setResources(value);
//			System.out.println("methodName = " + methodName);
//			System.out.println("request = " + request);
//			System.out.println("+++++++++++++++++++++++++++++++ CREATION AND SEND OF OfferEvent EVENT");
//			return event;
//		} else {
//			return null;
//		}
	}



}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/DriverProviderEvent_EventProducerNotifier.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;

import com.ebmwebsourcing.easybox.impl.AbstractJaxbModelObject;

public class DriverProviderEvent_EventProducerNotifier extends AbstractEventProducerNotifier {

	public DriverProviderEvent_EventProducerNotifier(ProviderConfiguration configuration, WSOUIJaxbContextItf context) throws WSOUIException {
		super(configuration, context);
		this.getSubscriptionManager().setTopicSet(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicSet.xml"));
		this.getSubscriptionManager().setTopicNamespace(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicNS.topns"));
	}

	@Override
	public void setPeriodEvent() {
		this.setPeriodEvent(0); // Set the period to send event (in ms).
	}


	@Override
	public Object createPeriodicallyEvent() throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeProcessingRequest(String methodName, Object request) throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeSendResponse(String methodName, Object request, Object response) throws WSOUIException {
		return null;
//		if(methodName.toLowerCase().equals("subscribe")) {
//			OfferEvent event = new OfferEvent();
//			event.setUid(UUID.randomUUID().toString());
//			Resources value = new Resources();
//			value.setQuantity(5.0);
//			value.setType("driver");
//			event.setProvider("driver");
//			event.setResources(value);
//			System.out.println("methodName = " + methodName);
//			System.out.println("request = " + request);
//			System.out.println("+++++++++++++++++++++++++++++++ CREATION AND SEND OF OfferEvent EVENT");
//			return event;
//		} else {
//			return null;
//		}
	}



}
